Learn R Programming

gstat (version 0.9-8)

bubble: Create a bubble plot of spatial data

Description

Create a bubble plot of spatial data, with options for bicolour residual plots (xyplot wrapper)

Usage

bubble(data, xcol = 1, ycol = 2, zcol = 3, fill = TRUE, maxsize = 3,
    do.sqrt = TRUE, pch, col = c(2,3), key.entries = quantile(data[,zcol]),
    ...)

Arguments

data
data frame from which x- and y-coordinate and z-variable are taken
xcol
x-coordinate column number or (quoted) name
ycol
y-coordinate column number or (quoted) name
zcol
z-variable column number or (quoted) name
fill
logical; if TRUE, filled circles are plotted (pch = 16), else open circles (pch = 1); the pch argument overrides this
maxsize
cex value for largest circle
do.sqrt
logical; if TRUE the plotting symbol area (sqrt(diameter)) is proportional to the value of the z-variable; if FALSE, the symbol size (diameter) is proportional to the z-variable
pch
plotting character
col
colours to be used; numeric vector of size two: first value is for negative values, second for positive values.
key.entries
the values that will be plotted in the key; by default the five quantiles min, q.25, median q.75, max
...
arguments, passed to xyplot

Value

  • returns (or plots) the bubble plot

See Also

xyplot, mapasp

Examples

Run this code
data(meuse)
bubble(meuse, max = 2.5, main = "cadmium concentrations (ppm)", 
    key.entries = c(.5,1,2,4,8,16))
bubble(meuse, "x", "y", "zinc", main = "zinc concentrations (ppm)",
    key.entries =  100 * 2^(0:4))

Run the code above in your browser using DataLab