estiStAni(empVgm, interval, method = "linear", spatialVgm, temporalVgm, s.range=NA, t.range=NA)linear, range, vgm or metric, see below for details)
vgm. The model is optimised based on the pure spatial values in empVgm.
vgm. The model is optimised based on the pure temporal values in empVgm.empVgm.
empVgm.
s.range and t.range).
joint component according to the defined spatial variogram spatialVgm. The starting value of stAni is the mean of the interval parameter (see vgmST for the metric variogram definition). The spatio-temporal anisotropy as estimated in the spatio-temporal variogram is returned. Note that the parameter interval is only used to set the starting value. Hence, the estimate might exceed the given interval.
data(vv)
estiStAni(vv, c(10, 150))
estiStAni(vv, c(10, 150), "vgm", vgm(80, "Sph", 120, 20))
Run the code above in your browser using DataLab