Learn R Programming

gstat (version 1.1-3)

jura: Jura data set

Description

The jura data set from Pierre Goovaerts' book (see references below). It contains four data.frames: prediction.dat, validation.dat and transect.dat and juragrid.dat, and three data.frames with consistently coded land use and rock type factors, as well as geographic coordinates. The examples below show how to transform these into spatial (sp) objects in a local coordinate system and in geographic coordinates, and how to transform to metric coordinate reference systems.

Usage

data(jura)

Arguments

Format

The data.frames prediction.dat and validation.dat contain the following fields:
Xloc
X coordinate, local grid km
Yloc
Y coordinate, local grid km
Landuse
see book and below
Rock
see book and below
Cd
mg cadmium kg^-1 topsoil
Co
mg cobalt kg^-1 topsoil
Cr
mg chromium kg^-1 topsoil
Cu
mg copper kg^-1 topsoil
Ni
mg nickel kg^-1 topsoil
Pb
mg lead kg^-1 topsoil
Zn
mg zinc kg^-1 topsoil
The data.frame juragrid.dat only has the first four fields. In addition the data.frames jura.pred, jura.val and jura.grid also have inserted third and fourth fields giving geographic coordinates:
long
Longitude, WGS84 datum
lat
Latitude, WGS84 datum

References

Goovaerts, P. 1997. Geostatistics for Natural Resources Evaluation. Oxford Univ. Press, New-York, 483 p. Appendix C describes (and gives) the Jura data set.

Atteia, O., Dubois, J.-P., Webster, R., 1994, Geostatistical analysis of soil contamination in the Swiss Jura: Environmental Pollution 86, 315-327

Webster, R., Atteia, O., Dubois, J.-P., 1994, Coregionalization of trace metals in the soil in the Swiss Jura: European Journal of Soil Science 45, 205-218

Examples

Run this code
data(jura)
summary(prediction.dat)
summary(validation.dat)
summary(transect.dat)
summary(juragrid.dat)

# the following commands were used to create objects with factors instead
# of the integer codes for Landuse and Rock:
## Not run: 
#   jura.pred = prediction.dat
#   jura.val = validation.dat
#   jura.grid = juragrid.dat
# 
#   jura.pred$Landuse = factor(prediction.dat$Landuse, 
# 	labels=levels(juragrid.dat$Landuse))
#   jura.pred$Rock = factor(prediction.dat$Rock, 
# 	labels=levels(juragrid.dat$Rock))
#   jura.val$Landuse = factor(validation.dat$Landuse, 
# 	labels=levels(juragrid.dat$Landuse))
#   jura.val$Rock = factor(validation.dat$Rock, 
# 	labels=levels(juragrid.dat$Rock))
# ## End(Not run)

# the following commands convert data.frame objects into spatial (sp) objects
#   in the local grid:
require(sp)
coordinates(jura.pred) = ~Xloc+Yloc
coordinates(jura.val) = ~Xloc+Yloc
coordinates(jura.grid) = ~Xloc+Yloc
gridded(jura.grid) = TRUE

# the following commands convert the data.frame objects into spatial (sp) objects
#   in WGS84 geographic coordinates
# example is given only for jura.pred, do the same for jura.val and jura.grid
# EPSG codes can be found by searching make_EPSG()
jura.pred <- as.data.frame(jura.pred)
coordinates(jura.pred) = ~ long + lat
proj4string(jura.pred) = CRS("+init=epsg:4326")
# display in Google Earth
if (require(maptools)) {
  kmlPoints(jura.pred,
		kmlfile="JuraPred.kml",
		kmlname="Jura Prediction Points",name=row.names(jura.pred@data),
		description=paste(jura.pred$Landuse, jura.pred$Rock, sep="/"))


  if (require(rgdal)) {
  # transform to UTM 32N
    jura.pred.utm32n = spTransform(jura.pred,
                                CRS("+init=epsg:32632"))
    coordnames(jura.pred.utm32n) = c("E","N")

    # transform to Swiss grid system CH1903 / LV03
    jura.pred.ch = spTransform(jura.pred,
                             CRS("+init=epsg:21781"))
    coordnames(jura.pred.ch) = c("X","Y")
  }
}

Run the code above in your browser using DataLab