Learn R Programming

gstat (version 0.9-8)

pcb: PCB138 measurements in sediment at the NCP, the Dutch part of the North Sea

Description

This data set gives a point set with altitudes, digitized from the 1:10,000 topographical map of the Netherlands.

Usage

data(pcb)

Arguments

References

http:/www.gstat.org/, http://www.rikz.nl/

Pebesma, E. J., & Duin, R. N. M. (2005). Spatial patterns of temporal change in North Sea sediment quality on different spatial scales. In P. Renard, H. Demougeot-Renard & R. Froidevaux (Eds.), Geostatistics for Environmental Applications: Proceedings of the Fifth European Conference on Geostatistics for Environmental Applications (pp. 367-378): Springer.

See Also

ncp.grid

Examples

Run this code
data(pcb)
library(lattice)
xyplot(y~x|as.factor(yf), pcb, aspect = "iso")
# demo(pcb)

Run the code above in your browser using DataLab