Learn R Programming

gstat (version 1.1-3)

spplot.vcov: Plot map matrix of prediction error variances and covariances

Description

Plot map matrix of prediction error variances and covariances

Usage

spplot.vcov(x, ...)

Arguments

x
Object of class SpatialPixelsDataFrame or SpatialGridDataFrame, resulting from a krige call with multiple variables (cokriging
...
remaining arguments passed to spplot

Value

spplot in package sp.